@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class MessageService(AppConfig):
-    name = 'message_service'
+    name = 'sparrow_cloud.apps.message_service'
