@@ -119,7 +119,7 @@ class RabbitMQConsumer(object):
                 "code": task_name
         }
         try:
-            os.environ["SPARROW_TASK_PARENT_OPTIONS"] = json.dumps(parent_options, cls=PythonObjectEncoder)
+            os.environ["SPARROW_TASK_PARENT_OPTIONS"] = json.dumps(parent_options, ensure_ascii=False, cls=PythonObjectEncoder)
         except:
             pass
         return parent_options
@@ -138,7 +138,7 @@ class RabbitMQConsumer(object):
         按照自定义PythonObjectEncoder进行json格式化, 若错误则同时返回异常, 若正常则同时返回空字符串
         """
         try:
-            json_result = json.dumps(result, cls=cls)
+            json_result = json.dumps(result, ensure_ascii=False, cls=cls)
             _t = ''
         except:
             json_result = str(result) if result else ''
@@ -157,8 +157,8 @@ class RabbitMQConsumer(object):
         task_info = {
                 "id": headers.get("task_id"), # from headers
                 "name": json_body.get("name"), # from body.name 
-                "task_args": json.dumps(json_body.get("args"), cls=PythonObjectEncoder), # from body.args
-                "task_kwargs": json.dumps(json_body.get("kwargs"), cls=PythonObjectEncoder), # from body.kwargs
+                "task_args": json.dumps(json_body.get("args"), ensure_ascii=False, cls=PythonObjectEncoder), # from body.args
+                "task_kwargs": json.dumps(json_body.get("kwargs"), ensure_ascii=False, cls=PythonObjectEncoder), # from body.kwargs
                 "origin": headers.get('origin'), # from headers
                 "created_time": delivery_info.get('created_time', None), # from headers
                 "exchange": delivery_info.get('exchange', None), # from headers
@@ -169,7 +169,7 @@ class RabbitMQConsumer(object):
                 "parent_code": parent_options.get('code', None), # from env
       
         }
-        return json.dumps(task_info, cls=PythonObjectEncoder)
+        return json.dumps(task_info, ensure_ascii=False, cls=PythonObjectEncoder)
 
     def do_work(self, connection, channel, method_frame, header_frame, body):
 
