@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class PermissionCommandConfig(AppConfig):
-    name = 'permission_command'
+    name = 'sparrow_cloud.apps.permission_command'
