@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class PingConfig(AppConfig):
-    name = 'ping'
+    name = 'sparrow_cloud.apps.ping'
