@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class SchemaCommandConfig(AppConfig):
-    name = 'schema_command'
+    name = 'sparrow_cloud.apps.schema_command'
