@@ -2,5 +2,5 @@ from django.apps import AppConfig
 
 
 class TableAPIService(AppConfig):
-    name = 'table_api'
+    name = 'sparrow_cloud.apps.table_api'
     verbose_name = 'table_api'
