@@ -6,6 +6,7 @@ class UserBase(object):
     def __init__(self, user_id):
         self._id = user_id
 
+    @property
     def is_authenticated(self):
         return True
 
@@ -15,4 +16,10 @@ class UserBase(object):
 
 
 class User(UserBase):
-    pass
\ No newline at end of file
+    def __init__(self, user_id, payload):
+        super().__init__(user_id)
+        self._payload = payload
+
+    @property
+    def payload(self):
+        return self._payload
\ No newline at end of file
