@@ -18,13 +18,13 @@ class JWTMiddleware(MiddlewareMixin):
         '''
         auth = get_authorization_header(request).split()
         # 如果没有token, 返回空
-        if not auth or auth[0].lower() != b'token':
+        if not auth or auth[0].lower() != b'token' or len(auth) != 2:
             request.META['REMOTE_USER'] = None
             request.META['payload'] = None
             return
 
-        token = auth[1]
         try:
+            token = auth[1]
             payload = decode_jwt(token, os.getenv("SC_JWT_PUBLIC_KEY"), "RS256")
             payload["token"] = token.decode('utf-8')
             user_id = payload.get("uid")
